@@ -18,6 +18,7 @@ class Snp:
             self.qry_pos = int(l[3]) - 1
             self.ref_length = int(l[-6])
             self.qry_length = int(l[-5])
+            self.reverse = {'1': False, '-1': True}[l[-3]]
             self.ref_name = l[-2]
             self.qry_name = l[-1]
         except:
@@ -36,6 +37,7 @@ class Snp:
             self.qry_pos + 1,
             self.ref_length,
             self.qry_length,
+            '-1' if self.reverse else '1',
             self.ref_name,
             self.qry_name
         ]])
